.. plone.app.widgets documentation master file, created by
   sphinx-quickstart on Tue Feb 11 12:03:17 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to plone.app.widgets's documentation!
=============================================

Contents:

.. toctree::
   :maxdepth: 2

   select_widget


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

